@@ -13,7 +13,7 @@ package Device::I2C::ADV7611;
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -217,6 +217,98 @@ sub writeEDIDTable {
     $io->writeIO( 0x15, 0xBE );
 }
 
+# check line state
+sub isPower {
+    my ($io) = @_;
+    return $io->readIO(0x0c) & 0x24;
+}
+
+sub isHDMI {
+    my ($io) = @_;
+    return $io->readHDMI(0x05) & 0x80;
+}
+
+sub isLockSTDI {
+    my ($io) = @_;
+    return $io->readCP(0xb1) & 0x80;
+}
+
+sub isTMDS {
+    my ($io) = @_;
+    return $io->readIO(0x6a) & 0x10;
+}
+
+sub isLockTMDS {
+    my ($io) = @_;
+    return $io->readIO(0x6a) & 0x43 == 0x43;
+}
+
+sub isSignal {
+    my ($io) = @_;
+    my $res;
+    $res = !$io->noPower();
+    $res &&= $io->isLockSTDI();
+    $res &&= $io->isTMDS();
+    $res &&= $io->isLockTMDS();
+}
+
+sub noLockCP {
+    my ($io) = @_;
+    return $io->readIO(0x12) & 0x01;
+}
+
+sub isFreeRun {
+    my ($io) = @_;
+    return $io->readCP(0xff) & 0x10;
+}
+
+# HDMI signal params
+sub getWidth {
+    my ($io) = @_;
+    return $io->readHDMI16(0x07) & 0x1fff;
+}
+
+sub getHeight {
+    my ($io) = @_;
+    return $io->readHDMI16(0x09) & 0x1fff;
+}
+
+sub getHFrontPorch {
+    my ($io) = @_;
+    return $io->readHDMI16(0x20) & 0x1fff;
+}
+
+sub getHSync {
+    my ($io) = @_;
+    return $io->readHDMI16(0x22) & 0x1fff;
+}
+
+sub getHBackPorch {
+    my ($io) = @_;
+    return $io->readHDMI16(0x24) & 0x1fff;
+}
+
+sub getVFrontPorch {
+    my ($io) = @_;
+    return ( $io->readHDMI16(0x2a) & 0x1fff ) / 2;
+}
+
+sub getVSync {
+    my ($io) = @_;
+    return ( $io->readHDMI16(0x2e) & 0x1fff ) / 2;
+}
+
+sub getVBackPorch {
+    my ($io) = @_;
+    return ( $io->readHDMI16(0x32) & 0x1fff ) / 2;
+}
+
+sub getFPS1000 {
+    my ($io) = @_;
+    my $fps = $io->readCP16(0xb8) & 0x1fff;
+    return 28636360 / 256 / $fps * 1000;
+}
+
 1;
 
 __END__
@@ -234,8 +326,8 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Device-I2C-ADV7611.svg?branch=build/master" alt="Travis status" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.07"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.07" alt="CPAN Testers result" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.07"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.07" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Device-I2C-ADV7611%200.08"><img src="https://badgedepot.code301.com/badge/cpantesters/Device-I2C-ADV7611/0.08" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Device-I2C-ADV7611-0.08"><img src="https://badgedepot.code301.com/badge/kwalitee/Device-I2C-ADV7611/0.08" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -243,7 +335,7 @@ Device::I2C::ADV7611 - I2C interface to ADV7611 using Device::I2C
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
